===========
Utilisation
===========

Pour utiliser ce package dans un travail, il vous suffit
de l'installer (voir :ref:`installation`) et ensuite de l'importer, de votre application:

.. code-block:: python

    import optel.datalake
